==> WeaponButtons_v0.06.zip: Interface/AddOns/WeaponButtons/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_WEAPONBUTTONSHEADER					= "Weapon Buttons";
BINDING_NAME_WEAPONBUTTONS							= "Weapon Buttons Toggle";

WEAPONBUTTONS_CONFIG_HEADER							= "Weapon Buttons";
WEAPONBUTTONS_CONFIG_HEADER_INFO					= "Contains settings for the Weapon Buttons,\nan AddOn which allows you to get access to just the weapon buttons of the character window.";

WEAPONBUTTONS_ENABLED								= "Enable Weapon Buttons";
WEAPONBUTTONS_ENABLED_INFO							= "Enables Weapon Buttons, which means that the Weapon Buttons window will be displayed.";

WEAPONBUTTONS_CHAT_ENABLED							= "Weapon Buttons enabled.";
WEAPONBUTTONS_CHAT_DISABLED							= "Weapon Buttons disabled.";

WEAPONBUTTONS_CHAT_COMMAND_ENABLE_INFO				= "Enables/disables Weapon Buttons.";

WEAPONBUTTONS_DISPLAY_TOOLTIPS						= "Show tooltips on Weapon Buttons";
WEAPONBUTTONS_DISPLAY_TOOLTIPS_INFO					= "Determines whether tooltips should be shown on mousing over the WeaponButtons.";

WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_ENABLED			= "Weapon Buttons display of tooltips enabled.";
WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_DISABLED		= "Weapon Buttons display of tooltips disabled.";

WEAPONBUTTONS_CHAT_COMMAND_DISPLAY_TOOLTIPS_INFO	= "Enables/disables the showing of tooltips when mousing over Weapon Buttons.";

WEAPONBUTTONS_LOCK_POSITION							= "Lock current position";
WEAPONBUTTONS_LOCK_POSITION_INFO					= "Prevents the user from dragging the WeaponButtons window from its current position.";

WEAPONBUTTONS_CHAT_LOCK_POSITION_ENABLED			= "Weapon Buttons have been locked to the current position.";
WEAPONBUTTONS_CHAT_LOCK_POSITION_DISABLED			= "Weapon Buttons have been unlocked from the current position.";

WEAPONBUTTONS_CHAT_COMMAND_LOCK_POSITION_INFO		= "Locks/unlocks the WeaponButtons to/from their current position.";

WEAPONBUTTONS_RESET									= "Reset position";
WEAPONBUTTONS_RESET_INFO							= "Resets the WeaponButtons position in case it's disappeared from the screen.";
WEAPONBUTTONS_RESET_NAME							= "Reset";
WEAPONBUTTONS_CHAT_COMMAND_RESET_INFO				= "Resets the position of the Weapon Buttons frame.";

==> WeaponButtons_v0.07.zip: Interface/AddOns/WeaponButtons/localization.lua <==
-- Version : English - sarf
-- Translation by : None

BINDING_HEADER_WEAPONBUTTONSHEADER					= "Weapon Buttons";
BINDING_NAME_WEAPONBUTTONS							= "Weapon Buttons Toggle";

WEAPONBUTTONS_CONFIG_HEADER							= "Weapon Buttons";
WEAPONBUTTONS_CONFIG_HEADER_INFO					= "Contains settings for the Weapon Buttons,\nan AddOn which allows you to get access to just the weapon buttons of the character window.";

WEAPONBUTTONS_ENABLED								= "Enable Weapon Buttons";
WEAPONBUTTONS_ENABLED_INFO							= "Enables Weapon Buttons, which means that the Weapon Buttons window will be displayed.";

WEAPONBUTTONS_CHAT_ENABLED							= "Weapon Buttons enabled.";
WEAPONBUTTONS_CHAT_DISABLED							= "Weapon Buttons disabled.";

WEAPONBUTTONS_CHAT_COMMAND_ENABLE_INFO				= "Enables/disables Weapon Buttons.";

WEAPONBUTTONS_DISPLAY_TOOLTIPS						= "Show tooltips on Weapon Buttons";
WEAPONBUTTONS_DISPLAY_TOOLTIPS_INFO					= "Determines whether tooltips should be shown on mousing over the WeaponButtons.";

WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_ENABLED			= "Weapon Buttons display of tooltips enabled.";
WEAPONBUTTONS_CHAT_DISPLAY_TOOLTIPS_DISABLED		= "Weapon Buttons display of tooltips disabled.";

WEAPONBUTTONS_CHAT_COMMAND_DISPLAY_TOOLTIPS_INFO	= "Enables/disables the showing of tooltips when mousing over Weapon Buttons.";

WEAPONBUTTONS_LOCK_POSITION							= "Lock current position";
WEAPONBUTTONS_LOCK_POSITION_INFO					= "Prevents the user from dragging the WeaponButtons window from its current position.";

WEAPONBUTTONS_CHAT_LOCK_POSITION_ENABLED			= "Weapon Buttons have been locked to the current position.";
WEAPONBUTTONS_CHAT_LOCK_POSITION_DISABLED			= "Weapon Buttons have been unlocked from the current position.";

WEAPONBUTTONS_CHAT_COMMAND_LOCK_POSITION_INFO		= "Locks/unlocks the WeaponButtons to/from their current position.";

WEAPONBUTTONS_RESET									= "Reset position";
WEAPONBUTTONS_RESET_INFO							= "Resets the WeaponButtons position in case it's disappeared from the screen.";
WEAPONBUTTONS_RESET_NAME							= "Reset";
WEAPONBUTTONS_CHAT_COMMAND_RESET_INFO				= "Resets the position of the Weapon Buttons frame.";

WEAPONBUTTONS_CHAT_COMMAND_INFO						= "Controls the weapon buttons by the command line. Use /weaponbutton to get usage help.";

WEAPONBUTTONS_CHAT_COMMAND_USAGE					= "Usage: /weaponbutton <show|tooltips|lock> [on|off|toggle]\nCommands:\n show - determines whether the WeaponButton window should be visible\n tooltips - whether tooltips should be shown on mouseover\n lock - whether the window can be moved or not";
